You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by js...@apache.org on 2006/08/08 23:47:11 UTC

svn commit: r429833 [3/5] - in /incubator/tuscany/cpp/sca: ./ doc/ projects/tuscany_sca/ projects/tuscany_sca/tuscany_sca/ projects/tuscany_sca/tuscany_sca_test/ projects/tuscany_sca/tuscany_sca_test/testSCASystem/composites/ projects/tuscany_sca/tusca...

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.h (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.h Tue Aug  8 14:47:01 2006
@@ -52,7 +52,7 @@
                 virtual void setOutputData(Operation operation, DataObjectPtr outputDataObject);
                 string entryPointName;
                 string systemRoot;
-                string moduleComponent;
+                string compositeComponent;
                 SCAEntryPoint* scaEntryPoint;
                 TuscanyRuntime* tuscanyRuntime;
             };

Modified: incubator/tuscany/cpp/sca/runtime/core/test/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/test/Makefile.am?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/test/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/runtime/core/test/Makefile.am Tue Aug  8 14:47:01 2006
@@ -1,28 +1,27 @@
 SUBDIRS = CustomerInfo MyValue src
 
 EXTRA_DIST = testSCASystem/subsystems \
-testSCASystem/modules/MyValueServiceModule/sca.module \
-testSCASystem/modules/MyValueServiceModule/*.fragment \
-testSCASystem/modules/MyValueServiceModule/*.componentType \
-testSCASystem/modules/MyValueServiceModule/*.wsdl \
-testSCASystem/modules/MyValueServiceModule/*.xsd \
-testSCASystem/modules/MyValueServiceModule/*.config
+testSCASystem/composites/MyValueServiceComposite/*.composite \
+testSCASystem/composites/MyValueServiceComposite/*.componentType \
+testSCASystem/composites/MyValueServiceComposite/*.wsdl \
+testSCASystem/composites/MyValueServiceComposite/*.xsd \
+testSCASystem/composites/MyValueServiceComposite/*.config
 
 
 BUILT_SOURCES = scagen
 
 scagen:
-	cp ./MyValue/MyValue.h ./testSCASystem/modules/MyValueServiceModule
-	cp ./MyValue/MyValueImpl.h ./testSCASystem/modules/MyValueServiceModule
-	cp ./MyValue/StockQuoteService.h ./testSCASystem/modules/MyValueServiceModule
-	cp ./CustomerInfo/CustomerInfo.h ./testSCASystem/modules/MyValueServiceModule
-	cp ./CustomerInfo/CustomerInfoImpl.h ./testSCASystem/modules/MyValueServiceModule
-	java -jar $(top_builddir)/tools/scagen/bld/scagen.jar -dir testSCASystem/modules/MyValueServiceModule -output tmp
+	cp ./MyValue/MyValue.h ./testSCASystem/composites/MyValueServiceComposite
+	cp ./MyValue/MyValueImpl.h ./testSCASystem/composites/MyValueServiceComposite
+	cp ./MyValue/StockQuoteService.h ./testSCASystem/composites/MyValueServiceComposite
+	cp ./CustomerInfo/CustomerInfo.h ./testSCASystem/composites/MyValueServiceComposite
+	cp ./CustomerInfo/CustomerInfoImpl.h ./testSCASystem/composites/MyValueServiceComposite
+	java -jar $(top_builddir)/tools/scagen/bld/scagen.jar -dir testSCASystem/composites/MyValueServiceComposite -output tmp
 	cp tmp/CustomerInfoImpl*.* CustomerInfo
 	cp tmp/MyValueImpl*.* MyValue
 	
                    
 install-exec-local:
-	cp CustomerInfo/.libs/libCustomerInfo.so testSCASystem/modules/MyValueServiceModule
-	cp MyValue/.libs/libMyValue.so testSCASystem/modules/MyValueServiceModule
+	cp CustomerInfo/.libs/libCustomerInfo.so testSCASystem/composites/MyValueServiceComposite
+	cp MyValue/.libs/libMyValue.so testSCASystem/composites/MyValueServiceComposite
 	

Modified: incubator/tuscany/cpp/sca/runtime/core/test/src/TestSCA.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/test/src/TestSCA.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/CustomerInfo.fragment (original)
+++ incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/CustomerInfo.fragment Tue Aug  8 14:47:01 2006
@@ -15,7 +15,7 @@
   limitations under the License.
  -->
 
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
 	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
 	xmlns:mvs="http://www.myvalue.org/MyValueService/"
 	name="CustomerInfoComponent">
@@ -32,5 +32,5 @@
 		</references>
 	</component>
 
-</moduleFragment>
+</compositeFragment>
 	

Added: incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,50 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+ -->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	xmlns:mvs="http://www.myvalue.org/MyValueService/"
+	name="MyValueServiceComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="MyValueServiceExport" multiplicity="1..1">
+		<interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+		<binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+		<reference>MyValueServiceComponent</reference>
+	</entryPoint>
+
+	<component name="MyValueServiceComponent">
+		<implementation.cpp dll="libMyValue.so" header="MyValueImpl.h"></implementation.cpp>
+		<properties>
+		</properties>
+		<references>
+			<stockQuote>StockQuoteService</stockQuote>
+		</references>
+	</component>
+
+	<externalService name="StockQuoteService">
+		<interface.cpp header="StockQuoteService.h"/>
+		<binding.ws port="http://www.webserviceX.NET/#wsdl.endpoint(StockQuote/StockQuoteSoap)"/>
+	</externalService>
+
+	<wire>
+		<source.uri>MyValueServiceComponent/customerInfo</source.uri>
+		<target.uri>CustomerInfoComponent</target.uri>
+	</wire>
+
+</composite>
+	
\ No newline at end of file

Modified: incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/subsystems/SubSystem1/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/subsystems/SubSystem1/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/subsystems/SubSystem1/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/subsystems/SubSystem1/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -19,9 +19,9 @@
  
 	name="SubSystem1">
 	
-	<moduleComponent name="MyValue" module="MyValueServiceModule">
+	<compositeComponent name="MyValue" composite="MyValueServiceComposite">
 		
-	</moduleComponent>
+	</compositeComponent>
 
 </subsystem>
 	

Modified: incubator/tuscany/cpp/sca/runtime/ws_reference/axis2c/src/Axis2Client.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/ws_reference/axis2c/src/Axis2Client.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/AccountClient.cpp (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/AccountClient.cpp Tue Aug  8 14:47:01 2006
@@ -41,7 +41,7 @@
 	{
 
         // Locate a service
-		ModuleContext myContext = ModuleContext::getCurrent();
+		CompositeContext myContext = CompositeContext::getCurrent();
 		AccountService *accountService = 
             (AccountService*) myContext.locateService("AccountServiceComponent");
 		if (accountService == 0)

Modified: incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.cmd Tue Aug  8 14:47:01 2006
@@ -40,9 +40,9 @@
 set APFULLDIR=%~d0%~p0
 set TUSCANY_SCACPP_SYSTEM_ROOT=%~d0%~p0\..\
 
-rem Only need to specify the subsystem (and not the moduleComponent as well) because
-rem there is only one moduleComponent in the subsystem - it is a very simple sample.
-set TUSCANY_SCACPP_DEFAULT_MODULE=BigBankSubsystem
+rem Only need to specify the subsystem (and not the compositeComponent as well) because
+rem there is only one compositeComponent in the subsystem - it is a very simple sample.
+set TUSCANY_SCACPP_DEFAULT_COMPOSITE=BigBankSubsystem
 
 rem Run the client
 

Modified: incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.sh?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/runclient.sh Tue Aug  8 14:47:01 2006
@@ -39,7 +39,7 @@
 export LD_LIBRARY_PATH=$TUSCANY_SCACPP/lib:$TUSCANY_SDOCPP/lib:$AXIS2C_HOME/lib:$LD_LIBRARY_PATH
 
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_SYSTEM
-export TUSCANY_SCACPP_DEFAULT_MODULE=BigBankSubsystem
+export TUSCANY_SCACPP_DEFAULT_COMPOSITE=BigBankSubsystem
 
 ./account_client 1234
 

Modified: incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Accounts.dsp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Accounts.dsp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Accounts.dsp (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Accounts.dsp Tue Aug  8 14:47:01 2006
@@ -232,7 +232,7 @@
 # End Source File
 # Begin Source File
 
-SOURCE=.\sca.module
+SOURCE=.\sca.composite
 # End Source File
 # Begin Source File
 

Modified: incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Makefile.am?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/Accounts/Makefile.am Tue Aug  8 14:47:01 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/BigBank/deploy
-moduledir=$(deploydir)/modules/Accounts
+compositedir=$(deploydir)/composites/Accounts
 
 BUILT_SOURCES = AccountDataServiceImpl_AccountDataService_Proxy.cpp \
 AccountDataServiceImpl_AccountDataService_Wrapper.cpp \
@@ -13,12 +13,12 @@
 
 noinst_HEADERS = *.h
 
-${BUILT_SOURCES}: sca.module
+${BUILT_SOURCES}: sca.composite
 	java -jar $(TUSCANY_SCACPP)/bin/scagen.jar -dir . -output .
 
-module_LTLIBRARIES = libAccounts.la
-module_DATA = sca.module.lin Tuscany-model.config *.componentType *.wsdl *.xsd services.xml
-EXTRA_DIST = sca.module.lin Tuscany-model.config *.componentType *.wsdl *.xsd services.xml
+composite_LTLIBRARIES = libAccounts.la
+composite_DATA = sca.composite.lin Tuscany-model.config *.componentType *.wsdl *.xsd services.xml
+EXTRA_DIST = sca.composite.lin Tuscany-model.config *.componentType *.wsdl *.xsd services.xml
 
 libAccounts_la_SOURCES = \
 AccountDataServiceImpl.cpp \
@@ -41,4 +41,4 @@
            -I${TUSCANY_SDOCPP}/include
 
 install-data-hook:
-	mv $(moduledir)/sca.module.lin $(moduledir)/sca.module
+	mv $(compositedir)/sca.composite.lin $(compositedir)/sca.composite

Added: incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite (added)
+++ incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,53 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+  Copyright (c) 2005 The Apache Software Foundation or its licensors, as applicable.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9"
+        name="Accounts">
+
+	<component name="AccountServiceComponent">
+		<implementation.cpp dll="Accounts.dll" header="AccountServiceImpl.h"/>
+		<references>
+			<AccountDataService>AccountDataServiceComponent</AccountDataService>
+			<stockQuote>StockQuoteServiceComponent</stockQuote>
+		</references>
+		<properties>
+			<v:currency>EURO</v:currency>
+		</properties>
+	</component>  
+
+	<component name="AccountDataServiceComponent">
+		<implementation.cpp dll="Accounts.dll" header="AccountDataServiceImpl.h"/>
+	</component>  
+
+	<component name="StockQuoteServiceComponent">
+		<implementation.cpp dll="Accounts.dll" header="StockQuoteServiceImpl.h"/>
+		<references>
+			<StockQuoteExternal>StockQuoteExternalService</StockQuoteExternal>
+		</references>
+	</component>  
+
+	<externalService name="StockQuoteExternalService">
+		<interface.cpp header="StockQuoteExternalService.h"/>
+		<binding.ws port="http://www.webserviceX.NET/#wsdl.endpoint(StockQuote/StockQuoteSoap)"/>
+	</externalService>
+
+	<entryPoint name="WSAccountEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="AccountService.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="http://www.bigbank.com/AccountService#wsdl.endpoint(AccountService/AccountServiceSOAP)"></binding.ws>
+		<reference>AccountServiceComponent</reference>
+	</entryPoint>
+     
+</composite>

Added: incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite.lin
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite.lin?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite.lin (added)
+++ incubator/tuscany/cpp/sca/samples/BigBank/Accounts/sca.composite.lin Tue Aug  8 14:47:01 2006
@@ -0,0 +1,53 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+  Copyright (c) 2005 The Apache Software Foundation or its licensors, as applicable.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9"
+        name="Accounts">
+
+	<component name="AccountServiceComponent">
+		<implementation.cpp dll="libAccounts.so" header="AccountServiceImpl.h"/>
+		<references>
+			<AccountDataService>AccountDataServiceComponent</AccountDataService>
+			<stockQuote>StockQuoteServiceComponent</stockQuote>
+		</references>
+		<properties>
+			<v:currency>EURO</v:currency>
+		</properties>
+	</component>  
+
+	<component name="AccountDataServiceComponent">
+		<implementation.cpp dll="libAccounts.so" header="AccountDataServiceImpl.h"/>
+	</component>  
+
+	<component name="StockQuoteServiceComponent">
+		<implementation.cpp dll="libAccounts.so" header="StockQuoteServiceImpl.h"/>
+		<references>
+			<StockQuoteExternal>StockQuoteExternalService</StockQuoteExternal>
+		</references>
+	</component>  
+
+	<externalService name="StockQuoteExternalService">
+		<interface.cpp header="StockQuoteExternalService.h"/>
+		<binding.ws port="http://www.webserviceX.NET/#wsdl.endpoint(StockQuote/StockQuoteSoap)"/>
+	</externalService>
+
+	<entryPoint name="WSAccountEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="AccountService.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="http://www.bigbank.com/AccountService#wsdl.endpoint(AccountService/AccountServiceSOAP)"></binding.ws>
+		<reference>AccountServiceComponent</reference>
+	</entryPoint>
+     
+</composite>

Modified: incubator/tuscany/cpp/sca/samples/BigBank/BigBank.ncb
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/BigBank.ncb?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
Binary files /tmp/tmpzR5xWG and /tmp/tmpdGVBXm differ

Modified: incubator/tuscany/cpp/sca/samples/BigBank/BigBankSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/BigBankSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/BigBankSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/BigBankSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -19,9 +19,9 @@
  
 	name="BigBankSubsystem">
 	
-	<moduleComponent name="AccountsService" module="Accounts">
+	<compositeComponent name="AccountsService" composite="Accounts">
 		
-	</moduleComponent>
+	</compositeComponent>
 
 </subsystem>
 	

Modified: incubator/tuscany/cpp/sca/samples/BigBank/deploy.bat
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/deploy.bat?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/deploy.bat (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/deploy.bat Tue Aug  8 14:47:01 2006
@@ -1,16 +1,16 @@
-copy Accounts\Debug\Accounts.dll Deploy\modules\Accounts
-copy Accounts\Debug\Accounts.pdb Deploy\modules\Accounts
-copy Accounts\AccountServiceImpl.h Deploy\modules\Accounts
-copy Accounts\AccountService.h Deploy\modules\Accounts
-copy Accounts\AccountDataServiceImpl.h Deploy\modules\Accounts
-copy Accounts\AccountDataService.h Deploy\modules\Accounts
-copy Accounts\StockQuoteService.h Deploy\modules\Accounts
-copy Accounts\StockQuoteServiceImpl.h Deploy\modules\Accounts
-copy Accounts\StockQuoteExternalService.h Deploy\modules\Accounts
-copy AccountClient\Debug\AccountClient.exe Deploy\modules\Accounts
-copy AccountClient\Debug\AccountClient.pdb Deploy\modules\Accounts
-copy Accounts\sca.module Deploy\modules\Accounts
+copy Accounts\Debug\Accounts.dll Deploy\composites\Accounts
+copy Accounts\Debug\Accounts.pdb Deploy\composites\Accounts
+copy Accounts\AccountServiceImpl.h Deploy\composites\Accounts
+copy Accounts\AccountService.h Deploy\composites\Accounts
+copy Accounts\AccountDataServiceImpl.h Deploy\composites\Accounts
+copy Accounts\AccountDataService.h Deploy\composites\Accounts
+copy Accounts\StockQuoteService.h Deploy\composites\Accounts
+copy Accounts\StockQuoteServiceImpl.h Deploy\composites\Accounts
+copy Accounts\StockQuoteExternalService.h Deploy\composites\Accounts
+copy AccountClient\Debug\AccountClient.exe Deploy\composites\Accounts
+copy AccountClient\Debug\AccountClient.pdb Deploy\composites\Accounts
+copy Accounts\sca.composite Deploy\composites\Accounts
 copy Accounts\sca.subsystem Deploy\subsystems\Accounts
-copy Accounts\AccountServiceImpl.componentType Deploy\modules\Accounts
-copy Accounts\AccountDataServiceImpl.componentType Deploy\modules\Accounts
-copy Accounts\StockQuoteServiceImpl.componentType Deploy\modules\Accounts
+copy Accounts\AccountServiceImpl.componentType Deploy\composites\Accounts
+copy Accounts\AccountDataServiceImpl.componentType Deploy\composites\Accounts
+copy Accounts\StockQuoteServiceImpl.componentType Deploy\composites\Accounts

Modified: incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/Makefile.am?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/Makefile.am Tue Aug  8 14:47:01 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/Calculator/deploy
-moduledir=$(deploydir)/modules/CalculatorModule
+compositedir=$(deploydir)/composites/CalculatorComposite
 
 BUILT_SOURCES = CalculatorImpl_CalculatorService_Proxy.cpp \
 CalculatorImpl_CalculatorService_Wrapper.cpp \
@@ -9,14 +9,14 @@
 
 noinst_HEADERS = *.h
 
-CalculatorImpl_CalculatorService_Proxy.cpp:
+${BUILT_SOURCES}: sca.composite
 	java -jar $(TUSCANY_SCACPP)/bin/scagen.jar -dir . -output .
 
-module_LTLIBRARIES = libCalculatorModule.la
-module_DATA = sca.module.lin Tuscany-model.config *.componentType *.wsdl services.xml
-EXTRA_DIST = sca.module.lin Tuscany-model.config *.componentType *.wsdl services.xml
+composite_LTLIBRARIES = libCalculatorComposite.la
+composite_DATA = sca.composite.lin Tuscany-model.config *.componentType *.wsdl services.xml
+EXTRA_DIST = sca.composite.lin Tuscany-model.config *.componentType *.wsdl services.xml
 
-libCalculatorModule_la_SOURCES = \
+libCalculatorComposite_la_SOURCES = \
 CalculatorImpl.cpp \
 CalculatorImpl_CalculatorService_Proxy.cpp \
 CalculatorImpl_CalculatorService_Wrapper.cpp \
@@ -25,11 +25,11 @@
 DivideServiceImpl_DivideService_Proxy.cpp \
 DivideServiceImpl_DivideService_Wrapper.cpp
 
-libCalculatorModule_la_LIBADD = -L${TUSCANY_SCACPP}/lib -ltuscany_sca
+libCalculatorComposite_la_LIBADD = -L${TUSCANY_SCACPP}/lib -ltuscany_sca
 
 INCLUDES = \
            -I$(TUSCANY_SCACPP)/include \
            -I${TUSCANY_SDOCPP}/include
 
 install-data-hook:
-	mv $(moduledir)/sca.module.lin $(moduledir)/sca.module
\ No newline at end of file
+	mv $(compositedir)/sca.composite.lin $(compositedir)/sca.composite
\ No newline at end of file

Added: incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,47 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+  Copyright 2006 The Apache Software Foundation or its licensors, as applicable.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+ -->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9"
+    xmlns:cs="tuscany/c/Calculator/"
+	name="CalculatorComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="WSCalculatorEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="Calculator.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="tuscany/c/Calculator#wsdl.endpoint(CalculatorService/CalculatorServicePort)"></binding.ws>
+		<reference>CalculatorServiceComponent</reference>
+	</entryPoint>
+
+
+	<component name="CalculatorServiceComponent">
+		<implementation.cpp dll="Calculator.dll" header="CalculatorImpl.h"></implementation.cpp>
+        <properties> </properties>
+		<references>
+	        <v:CalculatorDivideService>DivideServiceComponent/DivideService</v:CalculatorDivideService>
+	    </references>
+	</component>
+        
+	<component name="DivideServiceComponent">
+		<implementation.cpp dll="Calculator.dll" header="DivideServiceImpl.h"></implementation.cpp>
+        <properties> </properties>
+		<references> </references>
+	</component>
+        
+
+
+</composite>
\ No newline at end of file

Added: incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite.lin
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite.lin?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite.lin (added)
+++ incubator/tuscany/cpp/sca/samples/Calculator/CalculatorComposite/sca.composite.lin Tue Aug  8 14:47:01 2006
@@ -0,0 +1,42 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+  Copyright 2006 The Apache Software Foundation or its licensors, as applicable.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+ -->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	name="CalculatorComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="WSCalculatorEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="Calculator.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="tuscany/c/Calculator#wsdl.endpoint(CalculatorService/CalculatorServicePort)"></binding.ws>
+		<reference>CalculatorServiceComponent</reference>
+	</entryPoint>
+
+	<component name="CalculatorServiceComponent">
+		<implementation.cpp dll="libCalculatorComposite.so" header="CalculatorImpl.h"></implementation.cpp>
+                <properties> </properties>
+		<references>
+	               <v:CalculatorDivideService>DivideServiceComponent/DivideService</v:CalculatorDivideService>
+	        </references>
+	</component>
+        
+	<component name="DivideServiceComponent">
+		<implementation.cpp dll="libCalculatorComposite.so" header="DivideServiceImpl.h"></implementation.cpp>
+                <properties> </properties>
+		<references> </references>
+	</component>
+</composite>
\ No newline at end of file

Modified: incubator/tuscany/cpp/sca/samples/Calculator/CalculatorSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/CalculatorSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/CalculatorSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/CalculatorSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
 
 <subsystem xmlns="http://www.osoa.org/xmlns/sca/0.9" name="CalculatorSubsystem">
 	
-        <moduleComponent name="CalculatorService" module="CalculatorModule" />
+        <compositeComponent name="CalculatorService" composite="CalculatorComposite" />
 
 </subsystem>
 	

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Client/Calc.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Client/Calc.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Client/Calc.cpp (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Client/Calc.cpp Tue Aug  8 14:47:01 2006
@@ -68,7 +68,7 @@
 
     try
     {
-        // Set the default module environment variable: <subsystem>/<moduleName>
+        // Set the default  environment variable: <subsystem>/<Name>
         string systemRoot = getenv("TUSCANY_SCACPP");
         if (systemRoot  == "")
         {
@@ -77,15 +77,15 @@
         }
         systemRoot += "/../samples/Calculator/deploy";
         
-        char *defaultModule = "CalculatorSubsystem/CalculatorService";
+        char *defaultComposite = "CalculatorSubsystem/CalculatorService";
         
 //        TuscanyRuntime rt;
 //        rt.setSystemRoot(systemRoot);
-//        rt.setDefaultModuleComponent(defaultModule);
+//        rt.setDefaultCompositeComponent(defaultComposite);
 //        rt.start();
 
         // Locate a service
-		ModuleContext myContext = ModuleContext::getCurrent();
+		CompositeContext myContext = CompositeContext::getCurrent();
 		Calculator *calcService = (Calculator*) myContext.locateService("CalculatorServiceComponent");
 		if (calcService == 0)
 		{

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Client/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Client/Makefile.am?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Client/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Client/Makefile.am Tue Aug  8 14:47:01 2006
@@ -22,6 +22,6 @@
                     -laxis2_http_receiver
 	
 
-INCLUDES =  -I$(top_builddir)/Calculator/CalculatorModule \
+INCLUDES =  -I$(top_builddir)/Calculator/CalculatorComposite \
             -I${TUSCANY_SCACPP}/include \
             -I${TUSCANY_SDOCPP}/include

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Client/readme.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Client/readme.txt?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Client/readme.txt (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Client/readme.txt Tue Aug  8 14:47:01 2006
@@ -1,19 +1,19 @@
 Tuscany SCA for C++ Samples - Calculator Sample
 ===============================================
 
-This is a very simple sample to show how an SCA module with a single component
+This is a very simple sample to show how an SCA composite with a single component
 can be built and called from an executable.
 
 There are three sub projects in this workspace:
-    - CalculatorModule
-      This contains the source code and SCA artifacts for the SCA module. This
-      is the module that will be deployed into the SCA runtime.
+    - CalculatorComposite
+      This contains the source code and SCA artifacts for the SCA composite. This
+      is the composite that will be deployed into the SCA runtime.
     - CalculatorSubsystem
       This contains the sca.subsystem file which describes a subsystem to the 
       SCA runtime. 
     - Client
       An example client which will call the service exposed by the single component
-      in the CalculatorModule.
+      in the CalculatorComposite.
 
 
 Build instructions
@@ -30,25 +30,25 @@
 upwards of version 1.4.2).  Once scagen has successfully built, it can be run from the 
 sca/bin directory.
 
-1) Build the SCA module.
-    - Set CalculatorModule project as the active project.
+1) Build the SCA composite.
+    - Set CalculatorComposite project as the active project.
       Right click->Set as active project
 
     - Run the SCA generation tool to create the proxy and wrapper classes.
       Either Tools->SCA Gen if you have added SCA Gen as an external tool
       Or run from the command line: 
         scagen -dir <projectDirectory> -output <projectDirectory> 
-      where the projectDirectory is the directory with the sca.module file.
+      where the projectDirectory is the directory with the sca.composite file.
 
     - Rebuild All
       Build->Rebuild All
 
-2) Package and deploy the SCA module
+2) Package and deploy the SCA composite
     - There is a script file in the sca/samples/Calculator directory which will
       copy across all the files needed for deployment to the Tuscany runtime.
       On a command line run pack_deploy.cmd
       As a default, the sample will be copied to sca/samples/runtime directory
-      Both the SCA module and the subsystem will be copied.
+      Both the SCA composite and the subsystem will be copied.
 
 3) Build the client
     - Set the Client project as the active project.

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.cmd Tue Aug  8 14:47:01 2006
@@ -39,9 +39,9 @@
 
 set TUSCANY_SCACPP_SYSTEM_ROOT=%~d0%~p0\..\
 
-rem Only need to specify the subsystem (and not the moduleComponent as well) because
-rem there is only one moduleComponent in the subsystem - it is a very simple sample.
-set TUSCANY_SCACPP_DEFAULT_MODULE=CalculatorSubsystem
+rem Only need to specify the subsystem (and not the compositeComponent as well) because
+rem there is only one compositeComponent in the subsystem - it is a very simple sample.
+set TUSCANY_SCACPP_DEFAULT_COMPOSITE=CalculatorSubsystem
 
 rem Run the client
 

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.sh?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Client/runclient.sh Tue Aug  8 14:47:01 2006
@@ -39,7 +39,7 @@
 export LD_LIBRARY_PATH=$TUSCANY_SCACPP/lib:$TUSCANY_SDOCPP/lib:$AXIS2C_HOME/lib:$LD_LIBRARY_PATH
 
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_SYSTEM
-export TUSCANY_SCACPP_DEFAULT_MODULE=CalculatorSubsystem
+export TUSCANY_SCACPP_DEFAULT_COMPOSITE=CalculatorSubsystem
 
 ./calculator_client add 4.7 9
 ./calculator_client div 7.2 3.6

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am Tue Aug  8 14:47:01 2006
@@ -1,4 +1,4 @@
 deploydir=$(prefix)/samples/Calculator/deploy/subsystems/CalculatorSubsystem
-SUBDIRS = CalculatorModule Client WSClient
+SUBDIRS = CalculatorComposite Client WSClient
 EXTRA_DIST = CalculatorSubsystem
 deploy_DATA = CalculatorSubsystem/sca.subsystem

Modified: incubator/tuscany/cpp/sca/samples/GettingStarted.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/GettingStarted.html?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/GettingStarted.html (original)
+++ incubator/tuscany/cpp/sca/samples/GettingStarted.html Tue Aug  8 14:47:01 2006
@@ -91,7 +91,7 @@
                 <OL>
                   <LI>Create a new service folder in axis2:<BR/>                                      
                       &lt;AXIS2C_HOME&gt;/services/Calculator</LI>
-                  <LI>Copy the &lt;TUSCANY_SCACPP&gt;/samples/Calculator/CalculatorModule/services.xml                                       
+                  <LI>Copy the &lt;TUSCANY_SCACPP&gt;/samples/Calculator/CalculatorComposite/services.xml                                       
                       to &lt;AXIS2C_HOME&gt;/services/Calculator/services.xml</LI>
                   <LI>Edit the &lt;AXIS2C_HOME&gt;/services/Calculator/services.xml file to set the TuscanySystemRoot parameter to<BR/>
                       &lt;parameter name="TuscanySystemRoot" locked="xsd:false"&gt;&lt;tuscany_sca_install_dir&gt;/samples/Calculator/deploy&lt;/parameter&gt;<BR/>
@@ -179,7 +179,7 @@
                 <OL>
                   <LI>Create a new service folder in axis2:<BR/>                                      
                       &lt;AXIS2C_HOME&gt;/services/Calculator</LI>
-                  <LI>Copy the &lt;TUSCANY_SCACPP&gt;/samples/Calculator/CalculatorModule/services.xml                                       
+                  <LI>Copy the &lt;TUSCANY_SCACPP&gt;/samples/Calculator/CalculatorComposite/services.xml                                       
                       to &lt;AXIS2C_HOME&gt;/services/Calculator/services.xml</LI>
                   <LI>Edit the &lt;AXIS2C_HOME&gt;/services/Calculator/services.xml file to set the TuscanySystemRoot parameter to<BR/>
                       &lt;parameter name="TuscanySystemRoot" locked="xsd:false"&gt;&lt;TUSCANY_SCACPP&gt;/samples/Calculator/deploy&lt;/parameter&gt;<BR/>

Modified: incubator/tuscany/cpp/sca/samples/MyValue/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/Makefile.am?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/MyValue/Makefile.am Tue Aug  8 14:47:01 2006
@@ -1,23 +1,23 @@
-SUBDIRS = MyValueModule Client
+SUBDIRS = MyValueComposite Client
 
 deploy_dir = $(top_builddir)/samples/runtime
-deploy_module = $(deploy_dir)/modules/MyValueModule
+deploy_composite = $(deploy_dir)/composites/MyValueComposite
                    
 install-exec-local:
 	cp MyValueSubsystem/sca.subsystem $(deploy_dir)/subsystems/MyValueSubsystem
-	cp MyValueModule/sca.module $(deploy_module)
-	cp MyValueModule/CustomerInfo.fragment $(deploy_module)
-	cp MyValueModule/Tuscany-model.config $(deploy_module)
-	cp MyValueModule/CustomerInfo/CustomerInfoImpl.componentType $(deploy_module)/CustomerInfo
-	cp MyValueModule/CustomerInfo/.libs/libCustomerInfo.so $(deploy_module)/CustomerInfo
-	cp MyValueModule/CustomerInfo/CustomerInfo.h $(deploy_module)/CustomerInfo
-	cp MyValueModule/CustomerInfo/CustomerInfoImpl.h $(deploy_module)/CustomerInfo
-	cp MyValueModule/MyValue/MyValueImpl.componentType $(deploy_module)/MyValue
-	cp MyValueModule/MyValue/MyValue.h $(deploy_module)/MyValue
-	cp MyValueModule/MyValue/MyValueImpl.h $(deploy_module)/MyValue
-	cp MyValueModule/MyValue/MyValueService.wsdl $(deploy_module)/MyValue
-	cp MyValueModule/MyValue/.libs/libMyValue.so $(deploy_module)/MyValue
-	cp MyValueModule/StockQuoteService/StockQuoteService.h $(deploy_module)/StockQuoteService
-	cp MyValueModule/StockQuoteService/StockQuoteService.wsdl $(deploy_module)/StockQuoteService
+	cp MyValueComposite/sca.composite $(deploy_composite)
+	cp MyValueComposite/CustomerInfo.fragment $(deploy_composite)
+	cp MyValueComposite/Tuscany-model.config $(deploy_composite)
+	cp MyValueComposite/CustomerInfo/CustomerInfoImpl.componentType $(deploy_composite)/CustomerInfo
+	cp MyValueComposite/CustomerInfo/.libs/libCustomerInfo.so $(deploy_composite)/CustomerInfo
+	cp MyValueComposite/CustomerInfo/CustomerInfo.h $(deploy_composite)/CustomerInfo
+	cp MyValueComposite/CustomerInfo/CustomerInfoImpl.h $(deploy_composite)/CustomerInfo
+	cp MyValueComposite/MyValue/MyValueImpl.componentType $(deploy_composite)/MyValue
+	cp MyValueComposite/MyValue/MyValue.h $(deploy_composite)/MyValue
+	cp MyValueComposite/MyValue/MyValueImpl.h $(deploy_composite)/MyValue
+	cp MyValueComposite/MyValue/MyValueService.wsdl $(deploy_composite)/MyValue
+	cp MyValueComposite/MyValue/.libs/libMyValue.so $(deploy_composite)/MyValue
+	cp MyValueComposite/StockQuoteService/StockQuoteService.h $(deploy_composite)/StockQuoteService
+	cp MyValueComposite/StockQuoteService/StockQuoteService.wsdl $(deploy_composite)/StockQuoteService
 	
 

Modified: incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/CustomerInfo.fragment
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/CustomerInfo.fragment?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/CustomerInfo.fragment (original)
+++ incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/CustomerInfo.fragment Tue Aug  8 14:47:01 2006
@@ -15,7 +15,7 @@
   limitations under the License.
  -->
 
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
 	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
 	xmlns:mvs="http://www.myvalue.org/MyValueService/"
 	name="CustomerInfoComponent">
@@ -32,5 +32,5 @@
 		</references>
 	</component>
 
-</moduleFragment>
+</compositeFragment>
 	

Modified: incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/Makefile.am?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/Makefile.am Tue Aug  8 14:47:01 2006
@@ -4,7 +4,7 @@
 
 scagen:
 	cd $(top_builddir)/bin && \
-	./scagen.sh -dir $(prefix)/samples/MyValue/MyValueModule -output $(prefix)/samples/MyValue/MyValueModule
+	./scagen.sh -dir $(prefix)/samples/MyValue/MyValueComposite -output $(prefix)/samples/MyValue/MyValueComposite
 	mv CustomerInfoImpl_* CustomerInfo
 	mv MyValueImpl_* MyValue
 	

Added: incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,51 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+
+  Licensed under the Apache License, Version 2.0 (the "License");
+  you may not use this file except in compliance with the License.
+  You may obtain a copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+ -->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	xmlns:mvs="http://www.myvalue.org/MyValueService/"
+	name="MyValueComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="MyValueService" multiplicity="1..1">
+		<interface.wsdl interface="MyValue/MyValueService.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="mvs:MyValueServiceBinding"></binding.ws>
+		<reference>MyValueServiceComponent</reference>
+	</entryPoint>
+
+	<component name="MyValueServiceComponent">
+		<implementation.cpp dll="MyValue/libMyValue.so" header="MyValue/MyValueImpl.h"></implementation.cpp>
+		<properties>
+		</properties>
+		<references>
+			<customerInfo>CustomerInfoComponent</customerInfo>
+			<stockQuote>StockQuoteService</stockQuote>
+		</references>
+	</component>
+
+	<externalService name="StockQuoteService">
+		<interface.cpp header="StockQuoteService/StockQuoteService.h"/>
+		<binding.ws port="http://swanandmokashi.com#wsdl.endpoint(StockQuotes/StockQuotesSoap)"/>
+	</externalService>
+
+	<!--wire>
+		<source.uri>MyValueServiceComponent/customerInfo</source.uri>
+		<target.uri>CustomerInfoComponent</target.uri>
+	</wire-->
+
+</composite>
+	
\ No newline at end of file

Propchange: incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite
------------------------------------------------------------------------------
    svn:executable = *

Modified: incubator/tuscany/cpp/sca/samples/MyValue/MyValueSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/MyValueSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/MyValueSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/samples/MyValue/MyValueSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -19,9 +19,9 @@
  
 	name="MyValueSubsystem">
 	
-	<moduleComponent name="MyValue" module="MyValueModule">
+	<compositeComponent name="MyValue" composite="MyValueComposite">
 		
-	</moduleComponent>
+	</compositeComponent>
 
 </subsystem>
 	

Modified: incubator/tuscany/cpp/sca/samples/MyValue/runMyValueClient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/runMyValueClient.sh?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/runMyValueClient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/MyValue/runMyValueClient.sh Tue Aug  8 14:47:01 2006
@@ -45,7 +45,7 @@
 export LD_LIBRARY_PATH=$TUSCANY_SCACPP/lib:$TUSCANY_SDOCPP/lib:$LD_LIBRARY_PATH:$AXISCPP_DEPLOY/lib:$XERCES_DEPLOY/lib
 
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_ROOT/testSCASystem
-export TUSCANY_SCACPP_DEFAULT_MODULE=SubSystem1
+export TUSCANY_SCACPP_DEFAULT_COMPOSITE=SubSystem1
 
 cd $TUSCANY_SCACPP/bin/test
 ./tuscany_sca_test

Modified: incubator/tuscany/cpp/sca/samples/configure.ac
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/configure.ac?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/configure.ac (original)
+++ incubator/tuscany/cpp/sca/samples/configure.ac Tue Aug  8 14:47:01 2006
@@ -18,7 +18,7 @@
 
 AC_CONFIG_FILES([Makefile
                  Calculator/Makefile
-                 Calculator/CalculatorModule/Makefile
+                 Calculator/CalculatorComposite/Makefile
                  Calculator/Client/Makefile
                  Calculator/WSClient/Makefile
                  BigBank/Makefile

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator.ncb
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator.ncb?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
Binary files - no diff available.

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.dsp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.dsp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.dsp (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.dsp Tue Aug  8 14:47:01 2006
@@ -94,63 +94,63 @@
 # PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\Calculator.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\Calculator.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorDivideService_Proxy.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorDivideService_Proxy.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Proxy.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Proxy.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Proxy.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Proxy.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Wrapper.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Wrapper.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Wrapper.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Wrapper.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideService.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideService.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Proxy.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Proxy.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Proxy.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Proxy.h
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Wrapper.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Wrapper.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Wrapper.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Wrapper.h
 # End Source File
 # End Group
 # Begin Group "Header Files"
@@ -158,7 +158,7 @@
 # PROP Default_Filter "h;hpp;hxx;hm;inl"
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorDivideService_Proxy.h
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorDivideService_Proxy.h
 # End Source File
 # End Group
 # Begin Group "Resource Files"
@@ -166,11 +166,11 @@
 # PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\Calculator.wsdl
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\Calculator.wsdl
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\sca.module
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\sca.composite
 # End Source File
 # Begin Source File
 
@@ -178,11 +178,11 @@
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\services.xml
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\services.xml
 # End Source File
 # Begin Source File
 
-SOURCE="..\..\..\..\..\Calculator\CalculatorModule\Tuscany-model.config"
+SOURCE="..\..\..\..\..\Calculator\CalculatorComposite\Tuscany-model.config"
 # End Source File
 # End Group
 # End Target

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.mak
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.mak?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.mak (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/Calculator/Calculator.mak Tue Aug  8 14:47:01 2006
@@ -207,43 +207,43 @@
 
 
 !IF "$(CFG)" == "Calculator - Win32 Release" || "$(CFG)" == "Calculator - Win32 Debug"
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl.cpp
 
 "$(INTDIR)\CalculatorImpl.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)
 
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorDivideService_Proxy.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorDivideService_Proxy.cpp
 
 "$(INTDIR)\CalculatorImpl_CalculatorDivideService_Proxy.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)
 
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Proxy.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Proxy.cpp
 
 "$(INTDIR)\CalculatorImpl_CalculatorService_Proxy.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)
 
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Wrapper.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Wrapper.cpp
 
 "$(INTDIR)\CalculatorImpl_CalculatorService_Wrapper.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)
 
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl.cpp
 
 "$(INTDIR)\DivideServiceImpl.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)
 
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Proxy.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Proxy.cpp
 
 "$(INTDIR)\DivideServiceImpl_DivideService_Proxy.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)
 
 
-SOURCE=..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Wrapper.cpp
+SOURCE=..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Wrapper.cpp
 
 "$(INTDIR)\DivideServiceImpl_DivideService_Wrapper.obj" : $(SOURCE) "$(INTDIR)"
 	$(CPP) $(CPP_PROJ) $(SOURCE)

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/WSClient/BuildInstructions.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/WSClient/BuildInstructions.txt?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/WSClient/BuildInstructions.txt (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/WSClient/BuildInstructions.txt Tue Aug  8 14:47:01 2006
@@ -20,11 +20,11 @@
 TUSCANY_SDOCPP:
 The directory where the sdo runtime is deployed - probably something ending in sdo/deploy.
 
-TUSCANY_SCACPP_DEFAULT_MODULE=CalculatorSubsystem
-This is the default module to be loaded by SCA. It consists of <subsystem>/<component>
+TUSCANY_SCACPP_DEFAULT_COMPOSITE=CalculatorSubsystem
+This is the default composite to be loaded by SCA. It consists of <subsystem>/<component>
 
 TUSCANY_SCACPP_SYSTEM_ROOT
-This is the point from which SCA will start looking for modules to load. Again this is
+This is the point from which SCA will start looking for composites to load. Again this is
 set programmatically by the sample.
 
 AXIS2C_HOME:
@@ -39,9 +39,9 @@
 
 If required, go to the Calculator sample main directory, and
 type:
-"scagen -dir CalculatorModule -output CalculatorModule" 
+"scagen -dir CalculatorComposite -output CalculatorComposite" 
 
-The generated code is put into the CalculatorModule subdirectory.
+The generated code is put into the CalculatorComposite subdirectory.
 
 Building the Client project
 ===========================

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/deploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/deploy.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/deploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/deploy.cmd Tue Aug  8 14:47:01 2006
@@ -32,18 +32,18 @@
 set destinationPath=%2
 )
 
-if not exist %destinationPath%\modules mkdir %destinationPath%\modules 
-if not exist %destinationPath%\modules\CalculatorModule mkdir %destinationPath%\modules\CalculatorModule
+if not exist %destinationPath%\composites mkdir %destinationPath%\composites 
+if not exist %destinationPath%\composites\CalculatorComposite mkdir %destinationPath%\composites\CalculatorComposite
 
-copy %sourcePath%\CalculatorModule\*.componentType %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\sca.module %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\CalculatorImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideService.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideServiceImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Tuscany-model.config %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.wsdl %destinationPath%\modules\CalculatorModule
-copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\modules\CalculatorModule
+copy %sourcePath%\CalculatorComposite\*.componentType %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\sca.composite %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\CalculatorImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideService.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideServiceImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Tuscany-model.config %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.wsdl %destinationPath%\composites\CalculatorComposite
+copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\composites\CalculatorComposite
 
 if not exist %destinationPath%\bin mkdir %destinationPath%\bin
 copy %currentPath%\Client\%buildMode%\Client.exe %destinationPath%\bin

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/wsdeploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/wsdeploy.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/wsdeploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio6/projects/Calculator/wsdeploy.cmd Tue Aug  8 14:47:01 2006
@@ -33,18 +33,18 @@
 )
 
 
-if not exist %destinationPath%\modules mkdir %destinationPath%\modules 
-if not exist %destinationPath%\modules\CalculatorModule mkdir %destinationPath%\modules\CalculatorModule
+if not exist %destinationPath%\composites mkdir %destinationPath%\composites 
+if not exist %destinationPath%\composites\CalculatorComposite mkdir %destinationPath%\composites\CalculatorComposite
 
-copy %sourcePath%\CalculatorModule\*.componentType %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\sca.module %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\CalculatorImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideService.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideServiceImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Tuscany-model.config %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.wsdl %destinationPath%\modules\CalculatorModule
-copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\modules\CalculatorModule
+copy %sourcePath%\CalculatorComposite\*.componentType %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\sca.composite %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\CalculatorImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideService.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideServiceImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Tuscany-model.config %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.wsdl %destinationPath%\composites\CalculatorComposite
+copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\composites\CalculatorComposite
 
 if not exist %destinationPath%\bin mkdir       %destinationPath%\bin
 copy %currentPath%\WSClient\%buildMode%\WSClient.exe %destinationPath%\bin



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.cpp Tue Aug  8 14:47:01 2006
@@ -41,47 +41,47 @@
             }
 
             ///
             /// Add a new module component
             ///
-            Module* Subsystem::addModuleComponent(const std::string& name, const std::string& moduleName)
+            Composite* Subsystem::addCompositeComponent(const std::string& name, const std::string& compositeName)
             {
-                LOGENTRY(1, "Subsystem::addModuleComponent");
+                LOGENTRY(1, "Subsystem::addCompositeComponent");
                 
-                Module* newModule = new Module(moduleName);
+                Composite* newComposite = new Composite(compositeName);
                 
                 // TODO: Should check for duplicates and throw exception
-                moduleComponents[name] = newModule;
+                compositeComponents[name] = newComposite;
                 
-                LOGEXIT(1, "Subsystem::addModuleComponent");
+                LOGEXIT(1, "Subsystem::addCompositeComponent");
                 
-                return newModule;
+                return newComposite;
             }
             
-            Module* Subsystem::findModule(const std::string& moduleName)
+            Composite* Subsystem::findComposite(const std::string& compositeName)
             {
-                for (MODULECOMPONENT_MAP::iterator moduleComponentIter = moduleComponents.begin();
-                moduleComponentIter != moduleComponents.end();
-                moduleComponentIter++)
+                for (COMPOSITECOMPONENT_MAP::iterator compositeComponentIter = compositeComponents.begin();
+                compositeComponentIter != compositeComponents.end();
+                compositeComponentIter++)
                 {
-                    if (moduleName == moduleComponentIter->second->getName())
+                    if (compositeName == compositeComponentIter->second->getName())
                     {
-                        return (Module*)moduleComponentIter->second;
+                        return (Composite*)compositeComponentIter->second;
                     } 
                 }
                 return 0;
             }
             
-            Module* Subsystem::findModuleByComponentName(const std::string& moduleComponentName)
+            Composite* Subsystem::findCompositeByComponentName(const std::string& compositeComponentName)
             {
-                return moduleComponents[moduleComponentName];
+                return compositeComponents[compositeComponentName];
             }
             
-            Module* Subsystem::getDefaultModule()
+            Composite* Subsystem::getDefaultComposite()
             {
-                if (moduleComponents.size() == 1)
+                if (compositeComponents.size() == 1)
                 {
-                    MODULECOMPONENT_MAP::iterator moduleComponentIter = moduleComponents.begin();
-                    return moduleComponentIter->second;
+                    COMPOSITECOMPONENT_MAP::iterator compositeComponentIter = compositeComponents.begin();
+                    return compositeComponentIter->second;
                 }
                 return 0;
             }
@@ -106,11 +106,11 @@
 
             void Subsystem::resolveWires()
             {
-                for (MODULECOMPONENT_MAP::iterator moduleComponentIter = moduleComponents.begin();
-                moduleComponentIter != moduleComponents.end();
-                moduleComponentIter++)
+                for (COMPOSITECOMPONENT_MAP::iterator compositeComponentIter = compositeComponents.begin();
+                compositeComponentIter != compositeComponents.end();
+                compositeComponentIter++)
                 {
-                    moduleComponentIter->second->resolveWires();
+                    compositeComponentIter->second->resolveWires();
                 }
 
                 // Resolve EntryPoint wires
@@ -41,47 +41,47 @@
 
             ///
-            /// Add a new module component
+            /// Add a new composite component
             ///

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.h?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.h (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/Subsystem.h Tue Aug  8 14:47:01 2006
@@ -25,7 +25,7 @@
 #include <map>
 using std::map;
 
-#include "tuscany/sca/model/Module.h"
+#include "tuscany/sca/model/Composite.h"
 #include "tuscany/sca/model/EntryPoint.h"
 
 namespace tuscany
@@ -51,33 +51,33 @@
                 virtual ~Subsystem();
 
                 /**
                  * Add a new module component to the subsystem.
                  * @param name The name of the module component.
                  * @param moduleName The name of the module.
                  * @return The new Module added to the subsystem.
                  */
-                Module* addModuleComponent(const std::string& name, const std::string& moduleName);
+                Composite* addCompositeComponent(const std::string& name, const std::string& compositeName);
 
                 /**
                  * Find a module by module name.
                  * @param moduleName The name of the module to be found.
                  * @return The Module that was found, or 0 if not found.
                  */
-                Module* findModule(const std::string& moduleName);
+                Composite* findComposite(const std::string& compositeName);
 
                 /**
                  * Find a module by the module component name.
                  * @param moduleComponentName The module component name to be used to find
                  * the module.
                  * @return The Module that was found, or 0 if not found.
                  */
-                Module* findModuleByComponentName(const std::string& moduleComponentName);
+                Composite* findCompositeByComponentName(const std::string& compositeComponentName);
 
                 /**
                  * Get the default module set for this subsystem.
                  * @return The default module.
                  */
-                Module* getDefaultModule();
+                Composite* getDefaultComposite();
                 
                 /**
                  * Add an new entry point to the subsystem.
@@ -100,7 +100,7 @@
                 const std::string& getName() {return name;}
 
                 /**
-                 * Resolve all the wires configured in all the modules in this
+                 * Resolve all the wires configured in all the composites in this
                  * subsystem.
                  */
                 void resolveWires();
@@ -111,11 +111,11 @@
                  */
                 std::string name;
 
-                typedef std::map<std::string, Module*> MODULECOMPONENT_MAP;
+                typedef std::map<std::string, Composite*> COMPOSITECOMPONENT_MAP;
                 /**
                  * A map by module component name of modules.
                  */
-                MODULECOMPONENT_MAP moduleComponents; 
+                COMPOSITECOMPONENT_MAP compositeComponents; 
 
                 typedef map<string, EntryPoint*> ENTRYPOINT_MAP;
                 /**
@@ -51,33 +51,33 @@
 
                 /**
-                 * Add a new module component to the subsystem.
-                 * @param name The name of the module component.
-                 * @param moduleName The name of the module.
-                 * @return The new Module added to the subsystem.
+                 * Add a new composite component to the subsystem.
+                 * @param name The name of the composite component.
+                 * @param compositeName The name of the composite.
+                 * @return The new Composite added to the subsystem.
                  */
@@ -51,33 +51,33 @@
 
                 /**
-                 * Find a module by module name.
-                 * @param moduleName The name of the module to be found.
-                 * @return The Module that was found, or 0 if not found.
+                 * Find a composite by composite name.
+                 * @param compositeName The name of the composite to be found.
+                 * @return The Composite that was found, or 0 if not found.
                  */
@@ -51,33 +51,33 @@
 
                 /**
-                 * Find a module by the module component name.
-                 * @param moduleComponentName The module component name to be used to find
-                 * the module.
-                 * @return The Module that was found, or 0 if not found.
+                 * Find a composite by the composite component name.
+                 * @param compositeComponentName The composite component name to be used to find
+                 * the composite.
+                 * @return The Composite that was found, or 0 if not found.
                  */
@@ -51,33 +51,33 @@
 
                 /**
-                 * Get the default module set for this subsystem.
-                 * @return The default module.
+                 * Get the default composite set for this subsystem.
+                 * @return The default composite.
                  */
@@ -111,11 +111,11 @@
                 /**
-                 * A map by module component name of modules.
+                 * A map by composite component name of composites.
                  */

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.cpp Tue Aug  8 14:47:01 2006
@@ -67,34 +67,34 @@
             }
             
             // ====================================================================
             // Get a map of all the moduleComponents that use a particular module
             // ====================================================================
-            MODULE_LIST System::findModules(const std::string& name)
+            COMPOSITE_LIST System::findComposites(const std::string& name)
             {
-                LOGENTRY(1, "System::findModules");
-                MODULE_LIST foundModules;
+                LOGENTRY(1, "System::findComposites");
+                COMPOSITE_LIST foundComposites;
                 
                 SUBSYSTEM_MAP::iterator subsystemsIter;
                 for (subsystemsIter = subsystemMap.begin(); 
                 subsystemsIter != subsystemMap.end(); subsystemsIter++ ) {
-                    LOGINFO_1(2, "System::findModules: Found subsystem: %s", subsystemsIter->second->getName().c_str());
-                    // In each subsystem, find module components with this module defined
+                    LOGINFO_1(2, "System::findComposites: Found subsystem: %s", subsystemsIter->second->getName().c_str());
+                    // In each subsystem, find composite components with this composite defined
                     
-                    Module* module = subsystemsIter->second->findModule(name);
-                    if (module)
+                    Composite* composite = subsystemsIter->second->findComposite(name);
+                    if (composite)
                     {
-                        LOGINFO_1(2, "System::findModules: Found module: %s", module->getName().c_str());
-                        foundModules.push_back(module);
+                        LOGINFO_1(2, "System::findComposites: Found composite: %s", composite->getName().c_str());
+                        foundComposites.push_back(composite);
                     }
                 }   
-                LOGEXIT(1, "System::findModules");
+                LOGEXIT(1, "System::findComposites");
                 
-                return foundModules;
+                return foundComposites;
             }
 
             
             // ====================================================================
             // Get a map of all the moduleComponents that use a particular module
             // ====================================================================
             Subsystem* System::findSubsystem(const std::string& subsystem)
             {
@@ -67,34 +67,34 @@
             
             // ====================================================================
-            // Get a map of all the moduleComponents that use a particular module
+            // Get a map of all the compositeComponents that use a particular composite
             // ====================================================================
@@ -67,34 +67,34 @@
             
             // ====================================================================
-            // Get a map of all the moduleComponents that use a particular module
+            // Get a map of all the compositeComponents that use a particular composite
             // ====================================================================
             Subsystem* System::findSubsystem(const std::string& subsystem)

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.h?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.h (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/System.h Tue Aug  8 14:47:01 2006
@@ -32,7 +32,7 @@
     {
         namespace model
         {
-            typedef std::vector<Module*> MODULE_LIST;
+            typedef std::vector<Composite*> COMPOSITE_LIST;
 
             /**
              * The root of the runtime model supported by a Tuscany runtime.
@@ -56,16 +56,16 @@
                  */
                 Subsystem* findSubsystem(const std::string& subsystemName);
 
-                typedef std::vector<Module*> MODULE_LIST;
+                typedef std::vector<Composite*> COMPOSITE_LIST;
 
                 /**
                  * Return a vector of all the modules with a given module name.
                  * @param moduleName The name of the module to find
                  * @return A vector of all the times the module appears in the 
                  * system. It can be more than once because the same module name
                  * is used by more than one module component.
                  */
-                MODULE_LIST findModules(const std::string& moduleName);
+                COMPOSITE_LIST findComposites(const std::string& compositeName);
 
                 /**
                  * Resolve all the wires defined in the system.
@@ -56,16 +56,16 @@
 
                 /**
-                 * Return a vector of all the modules with a given module name.
-                 * @param moduleName The name of the module to find
-                 * @return A vector of all the times the module appears in the 
-                 * system. It can be more than once because the same module name
-                 * is used by more than one module component.
+                 * Return a vector of all the composites with a given composite name.
+                 * @param compositeName The name of the composite to find
+                 * @return A vector of all the times the composite appears in the 
+                 * system. It can be more than once because the same composite name
+                 * is used by more than one composite component.
                  */

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.cpp Tue Aug  8 14:47:01 2006
@@ -45,7 +45,7 @@
     scaEntryPoint = NULL;
     entryPointName = "";
     systemRoot = "";
-    moduleComponent = "";
+    compositeComponent = "";
     LOGEXIT(1,"EntryPointProxy::constructor");
 }
 
@@ -73,8 +73,8 @@
     try
 	{
 
 		// fullEntryPointName is of the form "subsystem name"/"module component name"/"entry point name"
 		// Get the "subsystem name"/"module component name" part for setDefaultModuleComponent
         // Keep the "entry point name" part for use in invoke
 		string subsystemAndComponentName, epName;
 		Utils::rTokeniseString("/", fullEntryPointName, subsystemAndComponentName, epName);
@@ -87,9 +87,9 @@
             newInitParams = true;
         }
 
-        if(moduleComponent.length() != 0 && moduleComponent != subsystemAndComponentName)
+        if(compositeComponent.length() != 0 && compositeComponent != subsystemAndComponentName)
         {
-            moduleComponent = subsystemAndComponentName;
+            compositeComponent = subsystemAndComponentName;
             newInitParams = true;
         }
 
@@ -103,17 +103,17 @@
         if(tuscanyRuntime == NULL)
         {
             LOGINFO(4, "Creating new TuscanyRuntime");
-            moduleComponent = subsystemAndComponentName;
+            compositeComponent = subsystemAndComponentName;
             systemRoot = systemRootPath;
             entryPointName = epName;
-            tuscanyRuntime = new TuscanyRuntime(moduleComponent, systemRoot);
+            tuscanyRuntime = new TuscanyRuntime(compositeComponent, systemRoot);
             tuscanyRuntime->start();
         }
         else if(tuscanyRuntime != NULL && newInitParams)
         {
-            LOGINFO(4, "Restarting TuscanyRuntime with new SystemRoot or DefaultModule");
+            LOGINFO(4, "Restarting TuscanyRuntime with new SystemRoot or DefaultComposite");
             tuscanyRuntime->stop();
-            tuscanyRuntime->setDefaultModuleComponent(moduleComponent);
+            tuscanyRuntime->setDefaultCompositeComponent(compositeComponent);
             tuscanyRuntime->setSystemRoot(systemRoot);
             tuscanyRuntime->start();
         }
@@ -169,9 +169,9 @@
     DataObjectPtr outputDataObject = NULL;
     SCARuntime* runtime = SCARuntime::getInstance();
     
-	Module* module = runtime->getCurrentModule();
+	Composite* composite = runtime->getCurrentComposite();
 
-	EntryPoint* entryPoint = module->findEntryPoint(entryPointName);
+	EntryPoint* entryPoint = composite->findEntryPoint(entryPointName);
 
     Binding* binding = entryPoint->getBinding();
     if(binding->getBindingType() == Binding::SCA)
@@ -188,7 +188,7 @@
         string wsdlPort  = wsBinding->getPortName();
         string wsdlService = wsBinding->getServiceName();
 
-        Wsdl* wsdl = module->findWsdl(wsdlNamespace);
+        Wsdl* wsdl = composite->findWsdl(wsdlNamespace);
         if (wsdl == 0)
         {
             LOGINFO_1(0, "WSDL description %s not found\n", wsdlNamespace.c_str());
@@ -509,7 +509,7 @@
 
     try
     {
         // Call into the wired module
         scaEntryPoint->invoke(operation);
 
         // Set the data in the outputDataObject to be returned
@@ -73,8 +73,8 @@
 	{
 
-		// fullEntryPointName is of the form "subsystem name"/"module component name"/"entry point name"
-		// Get the "subsystem name"/"module component name" part for setDefaultModuleComponent
+		// fullEntryPointName is of the form "subsystem name"/"composite component name"/"entry point name"
+		// Get the "subsystem name"/"composite component name" part for setDefaultCompositeComponent
         // Keep the "entry point name" part for use in invoke
 		string subsystemAndComponentName, epName;
@@ -509,7 +509,7 @@
     try
     {
-        // Call into the wired module
+        // Call into the wired composite
         scaEntryPoint->invoke(operation);
 

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/ws/EntryPointProxy.h?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/test/src/TestSCA.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/test/src/TestSCA.cpp Tue Aug  8 14:47:01 2006
@@ -34,7 +34,7 @@
     commonj::sdo::Logger::setLogging(20);
     cout << "Start of SCA test" << endl;
 
     // Set default module
     TuscanyRuntime runtime("SubSystem1");
 
     try
@@ -42,8 +42,8 @@
         runtime.start();
 
         // Locate a service
-        ModuleContext myContext = ModuleContext::getCurrent();
-        ModuleContext myContext2 = myContext;
+        CompositeContext myContext = CompositeContext::getCurrent();
+        CompositeContext myContext2 = myContext;
 
         MyValue* myService = (MyValue*) myContext.locateService("MyValueServiceComponent");
         if (myService == 0)
@@ -34,7 +34,7 @@
     cout << "Start of SCA test" << endl;
 
-    // Set default module
+    // Set default composite
     TuscanyRuntime runtime("SubSystem1");
 

Modified: incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/CustomerInfo.fragment
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/test/testSCASystem/composites/MyValueServiceComposite/CustomerInfo.fragment?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/ws_reference/axis2c/src/Axis2Client.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/ws_reference/axis2c/src/Axis2Client.cpp Tue Aug  8 14:47:01 2006
@@ -64,9 +64,9 @@
 
     string portNamespace = binding->getWSDLNamespaceURL();
 
     // Lookup the wsdl model from the module, keyed on the namespace 
     // (the wsdl will have been loaded at startup, based on the information in the config file)
-    Wsdl* wsdlDefinition = externalService->getContainingModule()->findWsdl(portNamespace);
+    Wsdl* wsdlDefinition = externalService->getContainingComposite()->findWsdl(portNamespace);
     if (wsdlDefinition == 0)
     {
     	string msg = "WSDL not found for " + portNamespace;
@@ -170,8 +170,8 @@
     	
     	// Build up the payload as an SDO
 
-        // Get the data factory for the module (it will already have the typecreates loaded for the xsds)
-      	DataFactoryPtr dataFactory = externalService->getContainingModule()->getDataFactory();
+        // Get the data factory for the composite (it will already have the typecreates loaded for the xsds)
+      	DataFactoryPtr dataFactory = externalService->getContainingComposite()->getDataFactory();
     	DataObjectPtr requestDO = dataFactory->create(wsdlOp.getInputTypeUri().c_str(), 
     	                                              wsdlOp.getInputTypeName().c_str());
     	
@@ -288,7 +288,7 @@
     {
         // Document style 
         
-        DataFactoryPtr dataFactory = externalService->getContainingModule()->getDataFactory();
+        DataFactoryPtr dataFactory = externalService->getContainingComposite()->getDataFactory();
         AxiomHelper myHelper;
         DataObjectPtr returnDO = myHelper.toSdo(ret_node, dataFactory);
         
@@ -64,9 +64,9 @@
     string portNamespace = binding->getWSDLNamespaceURL();
 
-    // Lookup the wsdl model from the module, keyed on the namespace 
+    // Lookup the wsdl model from the composite, keyed on the namespace 
     // (the wsdl will have been loaded at startup, based on the information in the config file)

Modified: incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/AccountClient.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/AccountClient/AccountClient.cpp?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================